@@ -1,25 +1,29 @@
 # -*- coding: utf-8 -*-
-"""The new **Sandbox Flow Configuration** aims to break many of the
+"""The new **Sandbox Flow Configuration** (``itype = 12``) aims to break many of the
 barriers to entry in a Navier-Stokes solver.
-The idea is to easily provide everything that X3d needs from a Python Jupyter
+The idea is to easily provide everything that XCompact3d needs from a Python Jupyter
 Notebook, like initial conditions, solid geometry, boundary conditions, and the
 parameters. For students in computational fluid dynamics, it provides a
 direct hands-on experience and a safe place for practicing and learning, while
 for advanced users and code developers, it works as a rapid prototyping tool.
+For more details, see:
 
-See https://github.com/fschuch/Xcompact3d/ for more information.
+   * `"A Jupyter sandbox environment coupled into the high-order Navier-Stokes solver Xcompact3d", by F.N. Schuch, F.D. Vianna, A. Mombach, J.H. Silvestrini. JupyterCon 2020. <https://www.fschuch.com/en/publication/2020-jupytercon/>`_
+
+   * `"Sandbox flow configuration: A rapid prototyping tool inside XCompact3d", by F.N. Schuch. XCompact3d 2021 Online Showcase Event. <https://www.fschuch.com/en/talk/sandbox-flow-configuration-a-rapid-prototyping-tool-inside-xcompact3d/>`_
 """
 
-from .array import X3dDataArray, X3dDataset
-from .mesh import get_mesh
-from .param import param
-import numpy as np
 import os.path
+
+import numpy as np
 import xarray as xr
 
+from .array import X3dDataArray, X3dDataset
+from .param import param
+
 
 def init_epsi(prm, dask=False):
-    """Initilizes the :math:`\\epsilon` arrays that define the solid geometry
+    """Initializes the :math:`\\epsilon` arrays that define the solid geometry
     for the Immersed Boundary Method.
 
     Parameters
@@ -29,7 +33,7 @@ def init_epsi(prm, dask=False):
 
     dask : bool
         Defines the lazy parallel execution with dask arrays.
-        See :obj:`xcompact3d_toolbox.x3d.pencil_decomp()`.
+        See :obj:`xcompact3d_toolbox.array.x3d.pencil_decomp()`.
 
     Returns
     -------
@@ -44,16 +48,16 @@ def init_epsi(prm, dask=False):
         Each one initialized with np.zeros(dtype=np.bool) and wrapped into a
         :obj:`xarray.DataArray` with the proper size, dimensions and coordinates.
         They are used to define the object(s) that is(are) going to be inserted
-        into the cartesiann domain by the Immersed Boundary Method (IBM).
+        into the cartesian domain by the Immersed Boundary Method (IBM).
         They should be set to one (True) at the solid points and stay
         zero (False) at the fluid points, some standard geometries are provided
-        by the accessor xcompact3d_toolbox.sandbox.geo.
+        by the accessor :obj:`xcompact3d_toolbox.sandbox.Geometry`.
 
     Examples
     -------
 
-    >>> prm = x3dx.Parameters()
-    >>> epsi = x3d.sandbox.init_epsi(prm)
+    >>> prm = xcompact3d_toolbox.Parameters()
+    >>> epsi = xcompact3d_toolbox.init_epsi(prm)
 
     """
 
@@ -64,16 +68,16 @@ def init_epsi(prm, dask=False):
 
     from os import makedirs
 
-    makedirs(os.path.join("data", "geometry"), exist_ok=True)
+    makedirs(os.path.join(prm.dataset.data_path, "geometry"), exist_ok=True)
 
-    mesh = get_mesh(prm)
+    mesh = prm.get_mesh()
 
     # the epsi array in the standard mesh (nx, ny, nz)
     fields = {"epsi": (mesh["x"], mesh["y"], mesh["z"])}
 
     if prm.iibm == 2:
         # Getting refined mesh
-        mesh_raf = get_mesh(prm, raf=True)
+        mesh_raf = prm.get_mesh(refined_for_ibm=True)
         # Three additional versions are needed if iibm = 2,
         # each one refined in one dimension by a factor nraf
         fields["xepsi"] = (mesh_raf["x"], mesh["y"], mesh["z"])
@@ -93,7 +97,7 @@ def init_epsi(prm, dask=False):
 
     # With 'file_name' attribute, we make sure that epsi will be written to disc,
     # while the refined versions are not needed
-    epsi["epsi"].attrs = {"file_name": os.path.join("data", "geometry", "epsilon")}
+    epsi["epsi"].attrs = {"file_name": os.path.join("geometry", "epsilon")}
 
     # Turns on lazy parallel execution with dask arrays
     if dask == True:
@@ -111,8 +115,8 @@ def init_epsi(prm, dask=False):
 
 def init_dataset(prm):
     """This function initializes a :obj:`xarray.Dataset` including all variables
-    that should be provided to Xcompact3d and the sandbox flow configuration,
-    according to the provided computational and physical parameters.
+    that should be provided to XCompact3d and the sandbox flow configuration,
+    according to the computational and physical parameters.
 
     Parameters
     ----------
@@ -129,7 +133,7 @@ def init_dataset(prm):
 
         * ``bxx1``, ``bxy1``, ``bxz1`` - Inflow boundary condition for ux, uy
           and uz, respectively (if nclx1 = 2);
-        * ``noise_mod_x1`` - for random noise modulation at inflow boudary
+        * ``noise_mod_x1`` - for random noise modulation at inflow boundary
           condition (if nclx1 = 2);
         * ``bxphi1`` - Inflow boundary condition for scalar field(s)
           (if nclx1 = 2 and numscalar > 0);
@@ -145,23 +149,26 @@ def init_dataset(prm):
           I = sum(vol_frc * ux) and them will correct streamwise velocity
           as ux = ux / I, so, set ``vol_frc`` properly.
 
-        After setting all values for your flow configuration, the dataset can be
-        written to disc with ``ds.x3d.write()``.
-
     Examples
-    -------
+    --------
 
-    >>> prm = x3dx.Parameters()
-    >>> dataset = x3d.sandbox.init_dataset(prm)
+    >>> prm = xcompact3d_toolbox.Parameters()
+    >>> dataset = xcompact3d_toolbox.init_dataset(prm)
+    >>> #
+    >>> # Code here your customized flow configuration
+    >>> #
+    >>> prm.dataset.write(dataset) # write the files to the disc
 
     """
 
     from os import makedirs
 
-    makedirs(os.path.join("data"), exist_ok=True)
+    makedirs(prm.dataset.data_path, exist_ok=True)
 
     # Init dataset
-    ds = xr.Dataset(coords=get_mesh(prm)).assign_coords({"n": range(prm.numscalar)})
+    ds = xr.Dataset(coords=prm.get_mesh()).assign_coords(
+        n=[n + 1 for n in range(prm.numscalar)]
+    )
 
     ds.x.attrs = {"name": "Streamwise coordinate", "long_name": r"$x_1$"}
     ds.y.attrs = {"name": "Vertical coordinate", "long_name": r"$x_2$"}
@@ -178,7 +185,7 @@ def init_dataset(prm):
                 dims=["y", "z"],
                 coords=[ds.y, ds.z],
                 attrs={
-                    "file_name": os.path.join("data", var),
+                    "file_name": var,
                     "name": f"Inflow Plane for {description.get(i,'')} Velocity",
                     "long_name": fr"$u_{i+1} (x_1=0,x_2,x_3)$",
                 },
@@ -195,7 +202,7 @@ def init_dataset(prm):
                 dims=["n", "y", "z"],
                 coords=[ds.n, ds.y, ds.z],
                 attrs={
-                    "file_name": os.path.join("data", "bxphi1"),
+                    "file_name": "bxphi1",
                     "name": "Inflow Plane for Scalar field(s)",
                     "long_name": r"$\varphi (x_1=0,x_2,x_3,n)$",
                 },
@@ -206,7 +213,7 @@ def init_dataset(prm):
                 dims=["n", "x", "z"],
                 coords=[ds.n, ds.x, ds.z],
                 attrs={
-                    "file_name": os.path.join("data", "byphi1"),
+                    "file_name": "byphi1",
                     "name": "Bottom Boundary Condition for Scalar field(s)",
                     "long_name": r"$\varphi (x_1,x_2=0,x_3,n)$",
                 },
@@ -217,7 +224,7 @@ def init_dataset(prm):
                 dims=["n", "x", "z"],
                 coords=[ds.n, ds.x, ds.z],
                 attrs={
-                    "file_name": os.path.join("data", "byphin"),
+                    "file_name": "byphin",
                     "name": "Top Boundary Condition for Scalar field(s)",
                     "long_name": r"$\varphi (x_1,x_2=L_2,x_3,n)$",
                 },
@@ -229,7 +236,7 @@ def init_dataset(prm):
             dims=["x", "y", "z"],
             coords=[ds.x, ds.y, ds.z],
             attrs={
-                "file_name": os.path.join("data", var),
+                "file_name": var,
                 "name": f"Initial Condition for {description.get(i,'')} Velocity",
                 "long_name": fr"$u_{str(i+1)} (x_1,x_2,x_3,t=0)$",
                 "BC": prm.get_boundary_condition(var),
@@ -241,7 +248,7 @@ def init_dataset(prm):
             dims=["n", "x", "y", "z"],
             coords=[ds.n, ds.x, ds.y, ds.z],
             attrs={
-                "file_name": os.path.join("data", "phi"),
+                "file_name": "phi",
                 "name": "Initial Condition for Scalar field(s)",
                 "long_name": r"$\varphi (x_1,x_2,x_3,n,t=0)$",
                 "BC": prm.get_boundary_condition("phi"),
@@ -254,7 +261,7 @@ def init_dataset(prm):
             dims=["x", "y", "z"],
             coords=[ds.x, ds.y, ds.z],
             attrs={
-                "file_name": os.path.join("data", "vol_frc"),
+                "file_name": "vol_frc",
                 "name": "Integral Operator for Flow Rate Control",
             },
         )
@@ -264,7 +271,7 @@ def init_dataset(prm):
 
 @xr.register_dataarray_accessor("geo")
 class Geometry:
-    """An acessor with some standard geometries for :obj:`xarray.DataArray`.
+    """An accessor with some standard geometries for :obj:`xarray.DataArray`.
     Use them in combination with the arrays initialized at
     :obj:`xcompact3d_toolbox.sandbox.init_epsi` and the new
     :obj:`xcompact3d_toolbox.genepsi.gene_epsi_3D`.
@@ -281,9 +288,9 @@ class Geometry:
         radius : float
             Cylinder's radius (the default is 0.5).
         axis : str
-            Cylinder's axis (the default is "z").
+            Cylinder's axis (the default is ``"z"``).
         height : float or None
-            Cylinder's height (the default is None), if None, it will occupates
+            Cylinder's height (the default is None), if None, it will take
             the entire axis, otherwise :math:`\pm h/2` is considered from the center.
         remp : bool
             Adds the geometry to the :obj:`xarray.DataArray` if True and removes
@@ -304,10 +311,10 @@ class Geometry:
         Examples
         -------
 
-        >>> prm = x3d.Parameters()
-        >>> epsi = x3d.sandbox.init_epsi(prm)
+        >>> prm = xcompact3d_toolbox.Parameters()
+        >>> epsi = xcompact3d_toolbox.init_epsi(prm)
         >>> for key in epsi.keys():
-        >>>     epsi[key] = epsi[key].geo.cylinder(x=4, y=5)
+        >>>     epsi[key] = epsi[key].geo.cylinder(x=4.0, y=5.0)
 
         """
 
@@ -326,7 +333,7 @@ class Geometry:
 
         if height != None:
             height *= 0.5
-            # Notice that r*10 is just to garantee that the values are larger than r
+            # Notice that r*10 is just to guarantee that the values are larger than r
             # and consequently outside the cylinder
             dis = dis.where(
                 self._data_array[axis] <= kwargs.get(axis, 0.0) + height, radius * 10
@@ -345,7 +352,7 @@ class Geometry:
         remp : bool
             Adds the geometry to the :obj:`xarray.DataArray` if True and removes
             it if False (the default is True).
-        **kwargs : float
+        **kwargs : tuple of float
             Box's boundaries.
 
         Returns
@@ -361,10 +368,10 @@ class Geometry:
         Examples
         -------
 
-        >>> prm = x3d.Parameters()
-        >>> epsi = x3d.sandbox.init_epsi(prm)
+        >>> prm = xcompact3d_toolbox.Parameters()
+        >>> epsi = xcompact3d_toolbox.init_epsi(prm)
         >>> for key in epsi.keys():
-        >>>     epsi[key] = epsi[key].geo.box(x=[2,5], y=[0,1])
+        >>>     epsi[key] = epsi[key].geo.box(x=(2,5), y=(0,1))
 
         """
 
@@ -410,8 +417,8 @@ class Geometry:
         Examples
         -------
 
-        >>> prm = x3d.Parameters()
-        >>> epsi = x3d.sandbox.init_epsi(prm)
+        >>> prm = xcompact3d_toolbox.Parameters()
+        >>> epsi = xcompact3d_toolbox.init_epsi(prm)
         >>> for key in epsi.keys():
         >>>     epsi[key] = epsi[key].geo.square(x=5, y=2, z=1)
 
@@ -467,8 +474,8 @@ class Geometry:
         Examples
         -------
 
-        >>> prm = x3d.Parameters()
-        >>> epsi = x3d.sandbox.init_epsi(prm)
+        >>> prm = xcompact3d_toolbox.Parameters()
+        >>> epsi = xcompact3d_toolbox.init_epsi(prm)
         >>> for key in epsi.keys():
         >>>     epsi[key] = epsi[key].geo.sphere(x=1, y=1, z=1)
 
@@ -518,8 +525,8 @@ class Geometry:
         Examples
         -------
 
-        >>> prm = x3d.Parameters()
-        >>> epsi = x3d.sandbox.init_epsi(prm)
+        >>> prm = xcompact3d_toolbox.Parameters()
+        >>> epsi = xcompact3d_toolbox.init_epsi(prm)
         >>> for key in epsi.keys():
         >>>     epsi[key] = epsi[key].geo.ahmed_body(x=2)
 
@@ -661,9 +668,9 @@ class Geometry:
         x = [1044.00 * s - adj + kwargs["x"], 1044.00 * s + kwargs["x"]]
         y = [338.00 * s + kwargs["y"], 338.00 * s - opo + kwargs["y"]]
 
-        coef = np.polyfit(x, y, 1)
+        coefficients = np.polyfit(x, y, 1)
 
-        cut = self._data_array.x * coef[0] + coef[1]
+        cut = self._data_array.x * coefficients[0] + coefficients[1]
 
         tmp = tmp.where(self._data_array.y <= cut, False)
 
@@ -686,8 +693,8 @@ class Geometry:
         Examples
         -------
 
-        >>> prm = x3d.Parameters()
-        >>> epsi = x3d.sandbox.init_epsi(prm)
+        >>> prm = xcompact3d_toolbox.Parameters()
+        >>> epsi = xcompact3d_toolbox.init_epsi(prm)
         >>> for key in epsi.keys():
         >>>     epsi[key] = epsi[key].geo.cylinder(x=4, y=5).geo.mirror("x")
 
@@ -696,39 +703,3 @@ class Geometry:
             self._data_array[dim] <= self._data_array[dim][-1] / 2.0,
             self._data_array[{dim: slice(None, None, -1)}].values,
         )
-
-    def visual3d(self):
-
-        import plotly.graph_objects as go
-        import plotly.offline as pyo
-        import plotly.io as pio
-
-        pio.renderers.default = "browser"  #'jupyterlab', 'vscode', 'nteract', 'notebook_connected', 'png', 'jpeg', 'jpg', 'svg', 'pdf', 'browser', 'sphinx_gallery'
-
-        X, Y, Z = np.mgrid[
-            0 : self._data_array.x[-1].values : self._data_array.x.shape[0] * 1j,
-            0 : self._data_array.y[-1].values : self._data_array.y.shape[0] * 1j,
-            0 : self._data_array.z[-1].values : self._data_array.z.shape[0] * 1j,
-        ]
-
-        values = (self._data_array * 1).values
-
-        fig = go.Figure()
-
-        # fig.add_scatter3d(x=X.flatten(), y=Y.flatten(), z=Z.flatten(), mode='markers',marker=dict(size=0.75))
-
-        fig.add_isosurface(
-            x=X.flatten(),
-            z=Y.flatten(),
-            y=Z.flatten(),
-            value=values.flatten(),
-            isomin=0.99,
-            isomax=1,
-            colorscale="sunset",
-            lighting=dict(ambient=0.4, specular=1.0),
-        )
-
-        fig.update_layout(scene_aspectmode="data")
-        fig.update_traces(showscale=False)
-
-        fig.show()
